#' Copper prices
#'
#' Monthly copper prices for 28 consecutive months (in constant 1997 dollars).
#'
#'
#' @format Time series data
#' @source Makridakis, Wheelwright and Hyndman (1998) \emph{Forecasting:
#' methods and applications}, John Wiley & Sons: New York. Chapter 9.
#' @keywords datasets
#' @examples
#' plot(copper1)
#'
"copper1"
